API Documentation
=================

The documentation on these pages is automatically generated from the source code. It provides an overview of all the
Python objects in the code base and as such is intended for Ganga core and extension developers. If you are a user of
Ganga then you probably want the :doc:`GPI documentation <../GPI/index>`.

:doc:`All Ganga modules <modules>`
